package com.ruoyi.oa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.oa.mapper.CmcSettleWorkMapper;
import com.ruoyi.oa.domain.CmcSettleWork;
import com.ruoyi.oa.service.ICmcSettleWorkService;

/**
 * cmc经费计算Service业务层处理
 * 
 * @author cmc
 * @date 2024-04-29
 */
@Service
public class CmcSettleWorkServiceImpl implements ICmcSettleWorkService 
{
    @Autowired
    private CmcSettleWorkMapper cmcSettleWorkMapper;

    /**
     * 查询cmc经费计算
     * 
     * @param settleId cmc经费计算主键
     * @return cmc经费计算
     */
    @Override
    public CmcSettleWork selectCmcSettleWorkBySettleId(String settleId)
    {
        return cmcSettleWorkMapper.selectCmcSettleWorkBySettleId(settleId);
    }

    /**
     * 查询cmc经费计算列表
     * 
     * @param cmcSettleWork cmc经费计算
     * @return cmc经费计算
     */
    @Override
    public List<CmcSettleWork> selectCmcSettleWorkList(CmcSettleWork cmcSettleWork)
    {
        return cmcSettleWorkMapper.selectCmcSettleWorkList(cmcSettleWork);
    }

    /**
     * 新增cmc经费计算
     * 
     * @param cmcSettleWork cmc经费计算
     * @return 结果
     */
    @Override
    public int insertCmcSettleWork(CmcSettleWork cmcSettleWork)
    {
        return cmcSettleWorkMapper.insertCmcSettleWork(cmcSettleWork);
    }

    /**
     * 修改cmc经费计算
     * 
     * @param cmcSettleWork cmc经费计算
     * @return 结果
     */
    @Override
    public int updateCmcSettleWork(CmcSettleWork cmcSettleWork)
    {
        return cmcSettleWorkMapper.updateCmcSettleWork(cmcSettleWork);
    }

    /**
     * 批量删除cmc经费计算
     * 
     * @param settleIds 需要删除的cmc经费计算主键
     * @return 结果
     */
    @Override
    public int deleteCmcSettleWorkBySettleIds(String[] settleIds)
    {
        return cmcSettleWorkMapper.deleteCmcSettleWorkBySettleIds(settleIds);
    }

    /**
     * 删除cmc经费计算信息
     * 
     * @param settleId cmc经费计算主键
     * @return 结果
     */
    @Override
    public int deleteCmcSettleWorkBySettleId(String settleId)
    {
        return cmcSettleWorkMapper.deleteCmcSettleWorkBySettleId(settleId);
    }
}
